@@ -1,7 +1,8 @@
-__version__ = "0.1.3"
+__version__ = "0.2.0"
 
 from .repr_str import *
 from .repr_rgb import *
 # from lovely_tensors.repr_plt import *
 from .repr_chans import *
-from .patch import *
\ No newline at end of file
+from .lo import *
+from .utils import *
\ No newline at end of file
